



gnuradio-config-info -v --prefix --sysconfdir --prefsdir --userprefsdir --prefs --builddate --enabled-components --cc --cxx --cflags
IF %ERRORLEVEL% NEQ 0 exit /B 1
python "%CONDA_PREFIX%/Library/share/gnuradio/examples/volk_benchmark/volk_math.py" -L test -N 1e6 -I 3 --all
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
